@@ -30,6 +30,7 @@ class LandingFeaturesSetReadContract(Contract):
 
 class LandingReadContract(Contract):
     name = serializers.CharField(max_length=32)
+    action = serializers.CharField(max_length=32)
     title = LandingTitleReadContract()
     body = LandingBodyReadContract()
     features_set = LandingFeaturesSetReadContract()
@@ -44,3 +45,4 @@ class LandingID(ID):
 class LandingPoint(ListPointMixin, ContractPoint):
     _point_id = LandingID()
     _read_contract = LandingReadContract
+    _sort_by = 'name'
