@@ -10,14 +10,14 @@ APP = 'operations'
 
 class OperationDescriptionReadContract(Contract):
     TO_WALLET_FROM_BANK_CARD = 'TO_WALLET_FROM_BANK_CARD'
-    FROM_WALLTET_TO_BANK_CARD = 'TO_BANK_CARD'
-    FROM_WALLTET_TO_WALLET = 'FROM_WALLTET_TO_WALLET'
-    TO_WALLTET_FROM_WALLET = 'TO_WALLTET_FROM_WALLET'
+    FROM_WALLET_TO_BANK_CARD = 'FROM_WALLET_TO_BANK_CARD'
+    FROM_WALLET_TO_WALLET = 'FROM_WALLET_TO_WALLET'
+    TO_WALLET_FROM_WALLET = 'TO_WALLET_FROM_WALLET'
     NAME_CHOICES = (
         (TO_WALLET_FROM_BANK_CARD, TO_WALLET_FROM_BANK_CARD),
-        (FROM_WALLTET_TO_BANK_CARD, FROM_WALLTET_TO_BANK_CARD),
-        (FROM_WALLTET_TO_WALLET, FROM_WALLTET_TO_WALLET),
-        (TO_WALLTET_FROM_WALLET, TO_WALLTET_FROM_WALLET),
+        (FROM_WALLET_TO_BANK_CARD, FROM_WALLET_TO_BANK_CARD),
+        (FROM_WALLET_TO_WALLET, FROM_WALLET_TO_WALLET),
+        (TO_WALLET_FROM_WALLET, TO_WALLET_FROM_WALLET),
     )
     RUB = 'RUB'
     USD = 'USD'
